@@ -1,11 +1,10 @@
 # Copyright (C) 2010, 2011 Sebastian Thiel (byronimo@gmail.com) and contributors
 #
 # This module is part of GitDB and is released under
-# the New BSD License: http://www.opensource.org/licenses/bsd-license.php
+# the New BSD License: https://opensource.org/license/bsd-3-clause/
 from gitdb.test.db.lib import (
     TestDBBase,
     with_rw_directory,
-    fixture_path
 )
 from gitdb.db import ReferenceDB
 
@@ -22,10 +21,9 @@ class TestReferenceDB(TestDBBase):
     def make_alt_file(self, alt_path, alt_list):
         """Create an alternates file which contains the given alternates.
         The list can be empty"""
-        alt_file = open(alt_path, "wb")
-        for alt in alt_list:
-            alt_file.write(alt.encode("utf-8") + "\n".encode("ascii"))
-        alt_file.close()
+        with open(alt_path, "wb") as alt_file:
+            for alt in alt_list:
+                alt_file.write(alt.encode("utf-8") + b"\n")
 
     @with_rw_directory
     def test_writing(self, path):
@@ -40,13 +38,13 @@ class TestReferenceDB(TestDBBase):
 
         # setup alternate file
         # add two, one is invalid
-        own_repo_path = fixture_path('../../../.git/objects')       # use own repo
+        own_repo_path = os.path.join(self.gitrepopath, 'objects')       # use own repo
         self.make_alt_file(alt_path, [own_repo_path, "invalid/path"])
         rdb.update_cache()
         assert len(rdb.databases()) == 1
 
         # we should now find a default revision of ours
-        gitdb_sha = hex_to_bin("5690fd0d3304f378754b23b098bd7cb5f4aa1976")
+        gitdb_sha = next(rdb.sha_iter())
         assert rdb.has_object(gitdb_sha)
 
         # remove valid
